@@ -3,7 +3,7 @@ use Moo;
 extends 'Search::Query::Field';
 use Scalar::Util qw( blessed );
 
-use namespace::sweep;
+use namespace::autoclean;
 
 has 'type'   => ( is => 'rw', default => sub {'char'} );
 has 'is_int' => ( is => 'rw', default => sub {0} );
@@ -23,7 +23,7 @@ has 'nullterm_query_class' =>
 has 'anyterm_query_class' =>
     ( is => 'rw', default => sub {'LucyX::Search::AnyTermQuery'} );
 
-our $VERSION = '0.201';
+our $VERSION = '0.202';
 
 =head1 NAME
 
